<?php

declare(strict_types=1);

namespace Drupal\media_iframe_cookie\Plugin\media\Source;

use Drupal\field\FieldConfigInterface;
use Drupal\media\MediaSourceBase;
use Drupal\media\MediaTypeInterface;

/**
 * External medias source.
 *
 * @MediaSource(
 *   id = "external_medias",
 *   label = @Translation("Iframe cookie"),
 *   description = @Translation("Provide external media source for iframe with cookies management."),
 *   allowed_field_types = {"string_long"},
 *   default_thumbnail_filename = "external_media.png",
 *   forms = {
 *     "media_library_add" = "Drupal\media_iframe_cookie\Form\ExternalMediaForm"
 *   }
 * )
 */
class ExternalMedias extends MediaSourceBase {

  /**
   * {@inheritdoc}
   */
  public function getMetadataAttributes(): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function createSourceField(MediaTypeInterface $type): FieldConfigInterface {
    /** @var \Drupal\field\FieldConfigInterface $sourceField */
    $sourceField = parent::createSourceField($type);
    $sourceField->set('label', $this->t('External media Iframe'));
    $sourceField->set('description', $this->t('Set external media iframe HTML code'));

    return $sourceField;
  }

}
